@@ -18,9 +18,9 @@ async def patient_httpx_client(*args, **kwargs):
 
 def get_openid_config_url(http_exception, url: str, app_id: Optional[str], tenant_id: Optional[str]) -> str:
     if tenant_id:
-        return url.replace("common", settings.internal_tenant_id)
+        return url.replace("common", tenant_id)
     elif app_id:
-        return f"{url}?appid={settings.internal_app_id}"
+        return f"{url}?appid={app_id}"
     else:
         event_id = capture_message("No valid app_id or tenant_id provided")
         raise http_exception(
